.tree-view .MuiTreeItem-root{padding-left:1rem;position:relative}.tree-view .MuiFormControlLabel-label,.tree-view .MuiTreeItem-label,.tree-view .MuiTypography-root{font-size:.8rem;font-weight:700}.tree-view .MuiTreeItem-group{padding-left:1rem;position:relative}.tree-view .MuiTreeItem-content:not(.no-before):before{border-bottom:1px solid #00000080;border-left:1px solid #00000080;content:"";height:1.5rem;left:0;position:absolute;top:.85rem;transform:translateY(-50%);width:1.5rem}.tree-view .MuiFormControlLabel-root{align-items:center;display:flex;justify-content:flex-start;position:relative;text-align:left;top:.16rem;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}
/*# sourceMappingURL=main.ec637c5a.css.map*/